@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 
 """
 Copyright (c) 2006-2019 sqlmap developers (http://sqlmap.org/)
@@ -14,6 +14,8 @@ def detect(get_page):
 
     for vector in WAF_ATTACK_VECTORS:
         page, _, _ = get_page(get=vector)
-        retval = "https://www.perimeterx.com/whywasiblocked" in (page or "")
+        retval |= "https://www.perimeterx.com/whywasiblocked" in (page or "")
+        if retval:
+            break
 
     return retval
